@@ -1,6 +1,7 @@
 from fastapi.exceptions import RequestValidationError
 from starlette.requests import Request
 from starlette.responses import JSONResponse
+from lantools.exception import SSOException
 
 async def request_validation_exception_handler_422(request: Request, exc: RequestValidationError) -> JSONResponse:
     """
@@ -37,4 +38,10 @@ async def request_validation_exception_handler_422(request: Request, exc: Reques
                 "debug": exc.errors()
             }
         },
+    )
+
+async def request_ssoexception_handler(request: Request, exc: SSOException) -> JSONResponse:
+    return JSONResponse(
+        status_code=200,
+        content=exc.output(),
     )
\ No newline at end of file
